@@ -80,6 +80,8 @@ class TokenType(AutoName):
     XOR = auto()
     DSTAR = auto()
 
+    URI_START = auto()
+
     BLOCK_START = auto()
     BLOCK_END = auto()
 
@@ -140,6 +142,7 @@ class TokenType(AutoName):
     TEXT = auto()
     MEDIUMTEXT = auto()
     LONGTEXT = auto()
+    BLOB = auto()
     MEDIUMBLOB = auto()
     LONGBLOB = auto()
     TINYBLOB = auto()
@@ -355,6 +358,7 @@ class TokenType(AutoName):
     PROCEDURE = auto()
     PROPERTIES = auto()
     PSEUDO_TYPE = auto()
+    PUT = auto()
     QUALIFY = auto()
     QUOTE = auto()
     RANGE = auto()
